////
////  AppSDKManager.m
////  blaccount_flutter_plugin
////
////  Created by 王振 on 2021/8/24.
////
//
#import "AppSDKManager.h"
#import <BLLetCore/BLLetCore.h>
#import <BLLetBase/BLLetBase.h>
#import <BLLetFamily/BLLetFamily.h>
#import <BLLetAccount/BLLetAccount.h>
#import <JSONKit-BroadLink/JSONKit.h>
#import "AFNetworking.h"

//字符串是否为空
#define BL_IsStrEmpty(_ref)    (((_ref) == nil) || ([(_ref) isEqual:[NSNull null]]) || ([@"" isEqualToString:(_ref)]))

@interface AppSDKManager ()

@property (strong,nonatomic)NSMutableArray <BLDNADevice *>*localDeviceArray;

@end

@implementation AppSDKManager

+(instancetype)sharedManager {
    static dispatch_once_t onceToken;
    static AppSDKManager *manager = nil;
    dispatch_once(&onceToken, ^{
        manager = [[self alloc] init];
    });
    return manager;
}
-(NSMutableArray<BLDNADevice *> *)localDeviceArray {
    if (_localDeviceArray == nil) {
        _localDeviceArray = [NSMutableArray array];
    }
    return _localDeviceArray;
}
-(BOOL)blAppSDKAccountInit {
    if ([BLLet sharedLet].configParam.companyId.length > 0) {
        [BLAccount sharedAccount];
        return YES;
    }else {
        return NO;
    }
}
-(void)loginWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] login:BL_IsStrEmpty([info objectForKey:@"account"]) ?@"" : [info objectForKey:@"account"] password:BL_IsStrEmpty([info objectForKey:@"password"]) ? @"" :[info objectForKey:@"password"] completionHandler:^(BLLoginResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg,
                @"data":@{//nickname,icon_path,sex,country_code,phone,email,birthday,user_type
                        @"login_session":result.loginsession?result.loginsession:@"",
                        @"user_id":result.userid?result.userid:@"",
                        @"nickname":result.nickname?result.nickname:@"",
                        @"icon_path":result.iconpath?result.iconpath:@"",
                        @"sex":result.sex?result.sex:@"",
                        @"country_code":result.countrycode?result.countrycode:@"",
                        @"phone":result.phone?result.phone:@"",
                        @"email":result.email?result.email:@"",
                        @"birthday":result.birthday?result.birthday:@"",
                        @"user_type":result.usertype?result.usertype:@"",
                }
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}

-(void)localLoginWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] localLoginWithUsrid:!BL_IsStrEmpty([info objectForKey:@"user_id"]) ?[info objectForKey:@"user_id"]:@"" session:!BL_IsStrEmpty([info objectForKey:@"login_session"]) ? [info objectForKey:@"login_session"]:@"" completionHandler:^(BLLoginResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
- (NSString *)changePhoneCountryCode:(NSString *)code {
    //手机号国家码统一修改为 00 开头
    if (BL_IsStrEmpty(code)) {
        return @"0086";
    }else if ([code hasPrefix:@"00"]) {
        return code;
    } else if ([code hasPrefix:@"+"]) {
        NSString *sub = [code substringFromIndex:1];
        return [NSString stringWithFormat:@"00%@", sub];
    } else {
        return [NSString stringWithFormat:@"00%@", code];
    }
}
-(void)fastLoginWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    NSString *countrycode;
    if ([info.allKeys containsObject:@"country_code"] && !BL_IsStrEmpty([info objectForKey:@"country_code"])) {
        countrycode = [self changePhoneCountryCode:[info objectForKey:@"account"]];
    }else {
        countrycode = @"";
    }
    [[BLAccount sharedAccount] fastLoginWithPhoneOrEmail:!BL_IsStrEmpty([info objectForKey:@"account"]) ? [info objectForKey:@"account"]:@"" countrycode:countrycode vcode:!BL_IsStrEmpty([info objectForKey:@"vcode"]) ? [info objectForKey:@"vcode"]:@"" logintry:@"false" completionHandler:^(BLLoginResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg,
                @"data":@{//nickname,icon_path,sex,country_code,phone,email,birthday,user_type
                        @"login_session":result.loginsession?result.loginsession:@"",
                        @"user_id":result.userid?result.userid:@"",
                        @"nickname":result.nickname?result.nickname:@"",
                        @"icon_path":result.iconpath?result.iconpath:@"",
                        @"sex":result.sex?result.sex:@"",
                        @"country_code":result.countrycode?result.countrycode:@"",
                        @"phone":result.phone?result.phone:@"",
                        @"email":result.email?result.email:@"",
                        @"birthday":result.birthday?result.birthday:@"",
                        @"user_type":result.usertype?result.usertype:@"",
                }
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
-(void)sendFastVCodeForLoginWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] sendFastVCode:!BL_IsStrEmpty([info objectForKey:@"account"]) ? [info objectForKey:@"account"]:@"" countryCode:!BL_IsStrEmpty([info objectForKey:@"country_code"]) ? [info objectForKey:@"country_code"]:nil completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}

-(void)sendPhoneCodeForRegisterWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] sendRegVCode:!BL_IsStrEmpty([info objectForKey:@"phone"]) ? [info objectForKey:@"phone"]:@"" countryCode:!BL_IsStrEmpty([info objectForKey:@"country_code"]) ? [info objectForKey:@"country_code"]:@""  completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}

-(void)sendEmailCodeForRegisterWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] sendRegVCode:!BL_IsStrEmpty([info objectForKey:@"email"]) ? [info objectForKey:@"email"]:@"" completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
-(void)registerAccountWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] regist:!BL_IsStrEmpty([info objectForKey:@"account"]) ? [info objectForKey:@"account"]:@""  password:!BL_IsStrEmpty([info objectForKey:@"password"]) ? [info objectForKey:@"password"]:@""  nickname:!BL_IsStrEmpty([info objectForKey:@"nickname"]) ? [info objectForKey:@"nickname"]:@""  vcode:!BL_IsStrEmpty([info objectForKey:@"code"]) ? [info objectForKey:@"code"]:@"" sex:BL_ACCOUNT_MALE birthday:!BL_IsStrEmpty([info objectForKey:@"birthday"]) ? [info objectForKey:@"birthday"]:@""  countryCode:!BL_IsStrEmpty([info objectForKey:@"country_code"]) ? [info objectForKey:@"country_code"]:@""  iconPath:!BL_IsStrEmpty([info objectForKey:@"iconpath"]) ? [info objectForKey:@"iconpath"]:@""  completionHandler:^(BLLoginResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg,
                @"data":@{//nickname,icon_path,sex,country_code,phone,email,birthday,user_type
                        @"login_session":result.loginsession?result.loginsession:@"",
                        @"user_id":result.userid?result.userid:@"",
                        @"nickname":result.nickname?result.nickname:@"",
                        @"icon_path":result.iconpath?result.iconpath:@"",
                        @"sex":result.sex?result.sex:@"",
                        @"country_code":result.countrycode?result.countrycode:@"",
                        @"phone":result.phone?result.phone:@"",
                        @"email":result.email?result.email:@"",
                        @"birthday":result.birthday?result.birthday:@"",
                        @"user_type":result.usertype?result.usertype:@"",
                }
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//重置密码发送验证码
-(void)resetPwdSendVCodeWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] sendRetriveVCode:!BL_IsStrEmpty([info objectForKey:@"account"]) ? [info objectForKey:@"account"]:@""  completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//重置密码
-(void)resetPwdWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] retrivePassword:!BL_IsStrEmpty([info objectForKey:@"account"]) ? [info objectForKey:@"account"]:@""  vcode:!BL_IsStrEmpty([info objectForKey:@"vcode"]) ? [info objectForKey:@"vcode"]:@"" newPassword:!BL_IsStrEmpty([info objectForKey:@"password"]) ? [info objectForKey:@"password"]:@"" completionHandler:^(BLLoginResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg,
                @"data":@{//nickname,icon_path,sex,country_code,phone,email,birthday,user_type
                        @"login_session":result.loginsession?result.loginsession:@"",
                        @"user_id":result.userid?result.userid:@"",
                        @"nickname":result.nickname?result.nickname:@"",
                        @"icon_path":result.iconpath?result.iconpath:@"",
                        @"sex":result.sex?result.sex:@"",
                        @"country_code":result.countrycode?result.countrycode:@"",
                        @"phone":result.phone?result.phone:@"",
                        @"email":result.email?result.email:@"",
                        @"birthday":result.birthday?result.birthday:@"",
                        @"user_type":result.usertype?result.usertype:@"",
                }
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//发送修改手机号的验证码，
-(void)sendVCodeToModifyPhoneWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] sendModifyVCode:!BL_IsStrEmpty([info objectForKey:@"phone"]) ? ([info objectForKey:@"phone"]):@"" countryCode:!BL_IsStrEmpty([info objectForKey:@"country_code"]) ? [info objectForKey:@"country_code"]:@"" completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//发送修改邮箱的验证码
-(void)sendVCodeToModifyEmailWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] sendModifyVCode:!BL_IsStrEmpty([info objectForKey:@"email"]) ? [info objectForKey:@"email"]:@"" completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//修改手机号
-(void)modifyPhoneWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] modifyPhone:!BL_IsStrEmpty([info objectForKey:@"phone"]) ? [info objectForKey:@"phone"]:@"" countryCode:!BL_IsStrEmpty([info objectForKey:@"country_code"]) ? [info objectForKey:@"country_code"]:@"" vcode:!BL_IsStrEmpty([info objectForKey:@"vcode"]) ? [info objectForKey:@"vcode"]:@"" password:!BL_IsStrEmpty([info objectForKey:@"password"]) ? [info objectForKey:@"password"]:@""  newpassword:nil completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//修改邮箱
-(void)modifyEmailWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] modifyEmail:!BL_IsStrEmpty([info objectForKey:@"email"]) ? [info objectForKey:@"email"]:@"" vcode:!BL_IsStrEmpty([info objectForKey:@"vcode"]) ?[info objectForKey:@"vcode"]:@"" password:!BL_IsStrEmpty([info objectForKey:@"password"]) ? [info objectForKey:@"password"]:@"" newpassword:nil completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//修改密码
-(void)modifyPwdWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    [[BLAccount sharedAccount] modifyPassword:!BL_IsStrEmpty([info objectForKey:@"old_password"]) ? [info objectForKey:@"old_password"]:@"" newPassword:!BL_IsStrEmpty([info objectForKey:@"new_password"]) ? [info objectForKey:@"new_password"]:@"" completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//修改昵称
-(void)modifyNickNameWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] modifyUserNickname:!BL_IsStrEmpty([info objectForKey:@"nickname"]) ? [info objectForKey:@"nickname"]:@"" completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//修改头像
-(void)modifyIncopathWithInfo:(NSDictionary *)info uccess:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] modifyUserIcon:!BL_IsStrEmpty([info objectForKey:@"file_path"]) ? [info objectForKey:@"file_path"]:@"" completionHandler:^(BLModifyUserIconResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
                @"data":@{@"icon_path":result.iconUrl?result.iconUrl:@""}
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//获取用户信息
-(void)getUserInfoWithInfo:(NSDictionary *)info uccess:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    NSArray *userIdArr = [self toArrayOrNSDictionary:[info objectForKey:@"data"]];
    [[BLAccount sharedAccount] getUserInfo:userIdArr.count > 0 ? userIdArr:@[] completionHandler:^(BLGetUserInfoResult * _Nonnull result) {
        if ([result succeed]) {
            NSMutableArray *array = [NSMutableArray array];
            for (BLUserInfo *userInfo in result.info) {
                NSDictionary *dic = @{
                    @"user_id":userInfo.userid?userInfo.userid:@"",
                    @"nickname":userInfo.nickname?userInfo.nickname:@"",
                    @"icon":userInfo.iconUrl?userInfo.iconUrl:@""
                };
                [array addObject:dic];
            }
            NSDictionary *resultDic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
                @"data":array
            };
            success(resultDic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}

//绑定第三方账号
-(void)bandThirdPartAccountWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] bindOauthAccount:BL_IsStrEmpty([info objectForKey:@"thirdtype"])?@"":[info objectForKey:@"thirdtype"] thirdID:BL_IsStrEmpty([info objectForKey:@"thirdid"])?@"":[info objectForKey:@"thirdid"] accesstoken:BL_IsStrEmpty([info objectForKey:@"accesstoken"])?@"":[info objectForKey:@"accesstoken"] extend:@{} completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}
//解绑第三方账号

-(void)unbandThirdPartAccountWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
    [[BLAccount sharedAccount] unbindOauthAccount:BL_IsStrEmpty([info objectForKey:@"thirdtype"])?@"":[info objectForKey:@"thirdtype"] thirdID:BL_IsStrEmpty([info objectForKey:@"thirdid"])?@"":[info objectForKey:@"thirdid"] topSign:BL_IsStrEmpty([info objectForKey:@"topsign"])?@"":[info objectForKey:@"topsign"] completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}

//发送销毁账号验证码
- (void)sendDestroyAccountCodeWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure{
    
    [[BLAccount sharedAccount] sendDestroyCodeWithPhoneOrEmail:BL_IsStrEmpty([info objectForKey:@"account"]) ?@"":[info objectForKey:@"account"] countryCode:BL_IsStrEmpty([info objectForKey:@"country_code"])?nil:[info objectForKey:@"country_code"] completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
    
}

- (NSDictionary *)getHeaderWithFamilyId:(NSString *)familyId countryCode:(NSString *)countryCode{
    long nowTime = (long) [[NSDate date] timeIntervalSince1970];
    NSString *language = [BLCommonTools getCurrentLanguage];
    NSString *lid = [BLConfigParam sharedConfigParam].licenseId;
    NSString *userid = [BLConfigParam sharedConfigParam].userid;
    NSString *session = [BLConfigParam sharedConfigParam].loginSession;
    NSString *countryCodeStr = BL_IsStrEmpty(countryCode)?@"":countryCode;
    NSDictionary *infoDic = [[NSBundle mainBundle] infoDictionary];
    NSString *appVersion = [infoDic objectForKey:@"CFBundleShortVersionString"];
    NSDictionary *header = @{
        @"timestamp" : [NSString stringWithFormat:@"%ld", nowTime],
        @"system" : @"iOS",
        @"appPlatform" : @"iOS",
        @"language" : language,
        @"appVersion" : appVersion,
        @"licenseid" : BL_IsStrEmpty(lid) ? @"" : lid,
        @"userid" : BL_IsStrEmpty(userid) ? @"" : userid,
        @"loginsession" : BL_IsStrEmpty(session) ? @"" : session,
        @"familyid" : BL_IsStrEmpty(familyId)?@"":familyId,
        @"countryCode" : countryCodeStr
    };
    return header;
}

//删除家庭数据
- (void)delAllFamilyWithPrimaryWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {

    AFHTTPSessionManager *manager = [AFHTTPSessionManager manager];
    manager.requestSerializer.timeoutInterval = 8.0f;
    
    AFSecurityPolicy *securityPolicy = [AFSecurityPolicy policyWithPinningMode:AFSSLPinningModeNone];
    // allowInvalidCertificates 是否允许无效证书（也就是自建的证书），默认为NO
    // 如果是需要验证自建证书，需要设置为YES
    securityPolicy.allowInvalidCertificates = YES;
    [securityPolicy setValidatesDomainName:NO];
    
    [manager setSecurityPolicy:securityPolicy];
    
    //设置内容请求响应类型
    manager.requestSerializer = [AFJSONRequestSerializer serializer];
    manager.responseSerializer = [AFJSONResponseSerializer serializer];
    manager.responseSerializer.acceptableContentTypes = [NSSet setWithObjects:@"application/json", @"text/json", @"text/javascript",@"text/html", @"text/plain", nil];
    NSString *url = [NSString stringWithFormat:@"%@/appsync/group/member/allfamilydel",[BLConfigParam sharedConfigParam].accountHost];
///appsync/group/member/allfamilydel
    NSMutableDictionary *resultHeader = [[NSMutableDictionary alloc] init];
    if ([BLConfigParam sharedConfigParam].isLoginMutexMode) {
        [resultHeader setObject:@"mutuallyexclusive" forKey:@"loginmode"];
    }
    NSDictionary *header = [self getHeaderWithFamilyId:[info objectForKey:@"familyid"] countryCode:[info objectForKey:@"country_code"]];

    if ([header isKindOfClass:[NSDictionary class]]) {
        NSArray *keysArray = header.allKeys;
        for (NSString *key in keysArray) {
            [resultHeader setObject:BL_IsStrEmpty([header objectForKey:key]) ? @"" : [header objectForKey:key] forKey:key];
        }
    }
    [manager POST:url parameters:nil headers:header progress:nil success:^(NSURLSessionDataTask * _Nonnull task, id  _Nullable responseObject) {
        BLBaseResult *result = [BLBaseResult BLS_modelWithJSON:responseObject];
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    } failure:^(NSURLSessionDataTask * _Nullable task, NSError * _Nonnull error) {
        NSDictionary *dic = @{
            @"status":@(3004),
            @"msg":@"The Internet is not available. Please check your network connection."
        };
        failure(dic);
    }];
}

//删除账号
-(void)deleteAccountWithInfo:(NSDictionary *)info success:(successIdWithBlock)success failure:(failureIdWithBlock)failure {
     [[BLAccount sharedAccount] destroyAccountWithPhoneOrEmail:BL_IsStrEmpty([info objectForKey:@"account"]) ?@"":[info objectForKey:@"account"] countryCode:BL_IsStrEmpty([info objectForKey:@"country_code"]) ?@"":[info objectForKey:@"country_code"] vcode:BL_IsStrEmpty([info objectForKey:@"vcode"]) ?@"":[info objectForKey:@"vcode"] completionHandler:^(BLBaseResult * _Nonnull result) {
        if ([result succeed]) {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@"",
            };
            success(dic);
        }else {
            NSDictionary *dic = @{
                @"status":@(result.status),
                @"msg":result.msg?result.msg:@""
            };
            failure(dic);
        }
    }];
}

#pragma mark - 设置请求头
+ (void)setHeaderWithAFHTTPSessionManager:(AFHTTPSessionManager *)manager header:(NSDictionary *)header {
    [header enumerateKeysAndObjectsUsingBlock:^(id  _Nonnull key, id  _Nonnull obj, BOOL * _Nonnull stop) {
        [manager.requestSerializer setValue:obj forHTTPHeaderField:key];
    }];
}




- (id)toArrayOrNSDictionary:(NSString *)jsonData{

    if (jsonData != nil) {
        NSData* data = [jsonData dataUsingEncoding:NSUTF8StringEncoding];
        id jsonObject = [NSJSONSerialization JSONObjectWithData:data options:NSJSONReadingAllowFragments error:nil];
        if (jsonObject != nil){
            return jsonObject;
        }else{
            // 解析错误
            return nil;

        }
    }
    return nil;
}



- (NSString *)p_toJsonString:(NSDictionary *)dic {
    if (dic == nil) {
        return @"";
    }
    NSError *error;
    NSData *data = [NSJSONSerialization dataWithJSONObject:dic options:0 error:&error];
    if (error) {
        NSLog(@"%@", error.localizedDescription);
        return nil;
    }

    return [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
}

- (NSDictionary *)p_toDictory:(id)json {
    if (!json || json == (id)kCFNull) return nil;
    NSDictionary *dic = nil;
    NSData *jsonData = nil;
    if ([json isKindOfClass:[NSDictionary class]]) {
        dic = json;
    } else if ([json isKindOfClass:[NSString class]]) {
        jsonData = [(NSString *)json dataUsingEncoding : NSUTF8StringEncoding];
    } else if ([json isKindOfClass:[NSData class]]) {
        jsonData = json;
    }
    if (jsonData) {
        dic = [NSJSONSerialization JSONObjectWithData:jsonData options:kNilOptions error:NULL];
        if (![dic isKindOfClass:[NSDictionary class]]) dic = nil;
    }
    return dic;
}
#pragma mark - BLControllerDelegate
- (Boolean)filterDevice:(BLDNADevice *)device {
    return NO;
}

- (Boolean)shouldAdd:(BLDNADevice *)device {
    //本地搜索到设备不会自动添加到SDK内
    return NO;
}

- (void)onDeviceUpdate:(BLDNADevice *)device isNewDevice:(Boolean)isNewDevice {
    BOOL isContain = NO;
    for (BLDNADevice *tempDevice in self.localDeviceArray) {
        if ([tempDevice.did isEqualToString:device.did]) {
            isContain = YES;
            tempDevice.controlId = device.controlId;
            tempDevice.controlKey = device.controlKey;
            tempDevice.lanaddr = device.lanaddr;
            tempDevice.newConfig = device.newConfig;
            break;
        }
    }
    if (!isContain) {
        [self.localDeviceArray addObject:device];
    }
}

- (NSString *)sharedPath {
    BLConfigParam *config = [BLConfigParam sharedConfigParam];
    return config.sdkFileSavePath;
}


@end
